==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkCellLocatorInterpolatedVelocityField.java <==
// java wrapper for vtkCellLocatorInterpolatedVelocityField object
//

package vtk;
import vtk.*;

public class vtkCellLocatorInterpolatedVelocityField extends vtkCompositeInterpolatedVelocityField
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetLastCellLocator_2();
  public vtkAbstractCellLocator GetLastCellLocator() {
    long temp = GetLastCellLocator_2();

    if (temp == 0) return null;
    return (vtkAbstractCellLocator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetCellLocatorPrototype_3();
  public vtkAbstractCellLocator GetCellLocatorPrototype() {
    long temp = GetCellLocatorPrototype_3();

    if (temp == 0) return null;
    return (vtkAbstractCellLocator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetCellLocatorPrototype_4(vtkAbstractCellLocator id0);
  public void SetCellLocatorPrototype(vtkAbstractCellLocator id0)
    { SetCellLocatorPrototype_4(id0); }

  private native void CopyParameters_5(vtkAbstractInterpolatedVelocityField id0);
  public void CopyParameters(vtkAbstractInterpolatedVelocityField id0)
    { CopyParameters_5(id0); }

  private native void AddDataSet_6(vtkDataSet id0);
  public void AddDataSet(vtkDataSet id0)
    { AddDataSet_6(id0); }

  private native void SetLastCellId_7(int id0,int id1);
  public void SetLastCellId(int id0,int id1)
    { SetLastCellId_7(id0,id1); }

  private native void SetLastCellId_8(int id0);
  public void SetLastCellId(int id0)
    { SetLastCellId_8(id0); }

  public vtkCellLocatorInterpolatedVelocityField() { super(); }

  public vtkCellLocatorInterpolatedVelocityField(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-armv6h.pkg.tar.xz: vtk/vtkCellLocatorInterpolatedVelocityField.java <==
// java wrapper for vtkCellLocatorInterpolatedVelocityField object
//

package vtk;
import vtk.*;

public class vtkCellLocatorInterpolatedVelocityField extends vtkCompositeInterpolatedVelocityField
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetLastCellLocator_2();
  public vtkAbstractCellLocator GetLastCellLocator() {
    long temp = GetLastCellLocator_2();

    if (temp == 0) return null;
    return (vtkAbstractCellLocator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetCellLocatorPrototype_3();
  public vtkAbstractCellLocator GetCellLocatorPrototype() {
    long temp = GetCellLocatorPrototype_3();

    if (temp == 0) return null;
    return (vtkAbstractCellLocator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetCellLocatorPrototype_4(vtkAbstractCellLocator id0);
  public void SetCellLocatorPrototype(vtkAbstractCellLocator id0)
    { SetCellLocatorPrototype_4(id0); }

  private native void CopyParameters_5(vtkAbstractInterpolatedVelocityField id0);
  public void CopyParameters(vtkAbstractInterpolatedVelocityField id0)
    { CopyParameters_5(id0); }

  private native void AddDataSet_6(vtkDataSet id0);
  public void AddDataSet(vtkDataSet id0)
    { AddDataSet_6(id0); }

  private native void SetLastCellId_7(int id0,int id1);
  public void SetLastCellId(int id0,int id1)
    { SetLastCellId_7(id0,id1); }

  private native void SetLastCellId_8(int id0);
  public void SetLastCellId(int id0)
    { SetLastCellId_8(id0); }

  public vtkCellLocatorInterpolatedVelocityField() { super(); }

  public vtkCellLocatorInterpolatedVelocityField(long id) { super(id); }
  public native long   VTKInit();

}
